/* SAPI_F.H - SAPI User Functions and data structs
   Copyright (c) 1996 Sangoma Technologies Inc.
   Author: Glenn Robins
   API v0.1, 16-bit

   Must #include <windows.h> before this header
*/

#define	SDLC_MDATALEN	544
#define	SDLC_HEADERLEN	15

/* SIP control block */
typedef struct {
	BYTE command;
	WORD buffer_length;
	BYTE return_code;
	BYTE sdlc_address;
	BYTE PF_bit;
	WORD poll_interval;
	BYTE general_mailbox_byte;
	BYTE reserved[6];
	BYTE data[SDLC_MDATALEN];
} SDLC_BLOCK;



/* SAPI will always return 1 */
int WINAPI SAPIAlive(void);

/* Initializes SAPI and loads SDLA driver, if not loaded already.
   A trace should be registered before this setup if one will
   be used at all, but is not necessary.
   Each application instance MUST call this on initialization.
   returns 0 if failed to load SDLA driver,
	   1 if this is the first setup call and the SDLA driver
	     loaded successfully,
	   2 if this is not the first successful setup call
	     (driver already loaded)
*/
int WINAPI SAPISetup(void);

/* Cleanup and unloads SDLA driver if this is the last
   application instance to use the driver.
   You must terminate your trace registration first if one
   was registered, unless you are the last application to use
   this DLL (but you shouldn't assume this).
   Each application instance MUST call this before closing.
   returns 1 always (return code reserved for future use)
*/
int WINAPI SAPICleanup(void);

/* Emulate XIP interrupt call with control block
   returns return_code value in structure
*/
char WINAPI SAPIControl(SDLC_BLOCK far *block, BYTE cardnumber);

/* returns 0 if a debugging command trace is already registered or
   had difficulty creating the window, 1 if successful.
   hWnd is a window to send notification messages to, and
   iMessage is a user-defined message that SAPI will send the
   application to signal an SAPI notification. The actual
   message code is passed by value to the WPARAM parameter
   of the window procedure
*/
char WINAPI SAPIRegisterDebug(HINSTANCE hInstance, HWND hWnd, UINT iMessage);

/* if a debugging command trace is active and instance matches that passed
   when registered (for security/fault tolerance purposes) then
   trace is terminated and returns 0. If instance doesn't match,
   returns 1. If no trace is running, returns 2.
   The trace is also terminated automatically if the window is
   closed (see trace messages)
*/
char WINAPI SAPITerminateDebug(HINSTANCE hInstance);

/* returns TRUE if a debugging command trace is registered and active */
BOOL WINAPI SAPIIsDebugRegistered(void);

/* DEBUGGING COMMAND TRACE MESSAGES (wParam values) */
#define	TRACEMSG_CLOSE	0

/*
   returns SDLAR_NOT_REGISTERED (0L) if failed to obtain a selector
	(any read or write calls to the board will result
	in a general protection fault)
   returns SDLAR_REGISTERED if succeeded (1L): the card's
	instance count was incremented but this is not the
	first registration call for this board (it is already
	in use by an application)
   returns SDLAR_ALLOCATED if succeeded (2L): the card's
	instance count was incremented and this is the
	first registration call for this board, and the
	memory selector was allocated
*/
int WINAPI SAPIRegisterCard(BYTE cardnumber);

/*
   returns SDLAR_NOT_REGISTERED (0L) if card wasn't registered
   returns SDLAR_DEREGISTERED (1L) if card's instance count
	was decremented but isn't currently zero
	(i.e. an application is still using the specified board)
   returns SDLAR_RELEASED (2L) if card is now not used by
	any application, and the selector was freed
*/
int WINAPI SAPIDeregisterCard(BYTE cardnumber);

/*
   returns a bit record (32-bit) of cards registered for use
	and cards that exist:
	[ E15 E14 ... E3 E2 E1 E0 R15 R14 ... R3 R2 R1 R0 ]
   For example, if bit R2 is set, then card 2 is registered
		if bit E2 is set, then card 2 exists
			(i.e. a configuration entry exists
			in WIN.INI)
*/
LRESULT WINAPI SAPIGetCards(void);

/*
   reads a block from the card's shared memory area
*/
void WINAPI SAPIReadSharedMemory(BYTE cardnumber, BYTE far *p, WORD offset, WORD length);


int WINAPI SAPIPrepareForLoading(BYTE cardnumber);
int WINAPI SAPILoadComplete(BYTE cardnumber);
unsigned char WINAPI SAPIReadPortByte(BYTE cardnumber, WORD offset);
void WINAPI SAPIWritePortByte(BYTE cardnumber, WORD offset, BYTE data);
unsigned char WINAPI SAPIReadByte(BYTE cardnumber, WORD offset);
void WINAPI SAPIWriteByte(BYTE cardnumber, WORD offset, BYTE data);
void WINAPI SAPIZeroWindow(BYTE cardnumber);

